@@ -22,12 +22,14 @@ class Config:
                  mongo_db_name: str,
                  mongo_cluster_url: str,
                  mongo_user_name: str,
-                 mongo_password: str):
+                 mongo_password: str,
+                 openai_organization_id: str = None):
         self.openai_api_key = openai_api_key
         self.mongo_db_name = mongo_db_name
         self.mongo_cluster_url = mongo_cluster_url
         self.mongo_user_name = mongo_user_name
         self.mongo_password = mongo_password
+        self.openai_organization_id = openai_organization_id
 
     @property
     def openai_client(self) -> types.ModuleType:
@@ -35,6 +37,9 @@ class Config:
         OpenAI client
         """
         openai.api_key = self.openai_api_key
+
+        if self.openai_organization_id is not None:
+            openai.organization = self.openai_organization_id
         return openai
 
     @property
